<?php
/*
  Template Name: Contact Page
 */
$errMsg = '';
$succMsg = '';
$nameError = '';
$emailError = '';
$commentError = '';
if (isset($_POST['submitted'])) {
    if (trim($_POST['contactName']) === '') {
        $nameError = __('Please enter your name.', 'andrina-lite');
        $hasError = true;
    } else {
        $name = wp_kses_post(trim($_POST['contactName']));
    }
    if (trim($_POST['email']) === '') {
        $emailError = __('Please enter your email address.', 'andrina-lite');
        $hasError = true;
    } else if (!filter_var($_POST['email'], FILTER_VALIDATE_EMAIL)) {
        $emailError = __('You entered an invalid email address.', 'andrina-lite');
        $hasError = true;
    } else {
        $email = wp_kses_post(trim($_POST['email']));
    }
    if (trim($_POST['comments']) === '') {
        $commentError = __('Please enter a message.', 'andrina-lite');
        $hasError = true;
    } else {
        if (function_exists('stripslashes')) {
            $comments = stripslashes(trim($_POST['comments']));
        } else {
            $comments =  wp_kses_post(trim($_POST['comments']));
        }
    }
    if (andrina_get_option('andrina_contact_captcha') == 'on') {
        if (isset($_POST['g-recaptcha-response']) && !empty($_POST['g-recaptcha-response'])):
            //your site secret key
            $secret = esc_attr(andrina_get_option('andrina_captcha_secret_key'));
            //get verify response data
            $verifyResponse = wp_enqueue_style('https://www.google.com/recaptcha/api/siteverify?secret=' . $secret . '&response=' . $_POST['g-recaptcha-response']);
            $responseData = json_decode($verifyResponse, true);
            if ($responseData["success"]) {
                // verified!
            } else {
                $hasError = true;
                $errMsg = $responseData["error-codes"][0];
            }
        else:
            $hasError = true;
            $errMsg = __('Please click on the reCAPTCHA box.', 'andrina-lite');
        endif;
    }
    if (!isset($hasError)) {
        $emailTo = get_option('tz_email');
        if (!isset($emailTo) || ($emailTo == '')) {
            $emailTo = get_option('admin_email');
        }
        $subject = __('[PHP Snippets] From ', 'andrina-lite') . $name;
        $body = sprintf("Name: %1$s \n\nEmail: %2$s \n\nComments: %3$s", $name, $email, $comments);
        $headers = 'From: ' . $name . ' <' . $emailTo . '>' . "\r\n" . 'Reply-To: ' . $email;
        wp_mail($emailTo, $subject, $body, $headers);
        $emailSent = true;
    }
}
get_header();
?>
<div class="clear"></div>
<div class="page_head">
    <div class="contact-line">
        <?php if (have_posts()) : the_post(); ?>
            <h1 class="page_title contact single-heading"><?php the_title(); ?></h1>
        <?php endif; ?>	
    </div>
</div>
<div class="page-content">

    <div class="row">
        <div class="col-md-8 col-sm-8">
            <div class="content-bar">
                <div class="contact_page"> 
                    <?php
                    the_content();
                    if (isset($emailSent) && $emailSent == true) {
                        ?>
                        <div class="thanks">
                            <p><?php _e('Thanks, your email was sent successfully.', 'andrina-lite'); ?></p>
                        </div>
                        <?php
                    } else {
                        if (isset($hasError) || isset($captchaError)) {
                            ?>
                            <p class="error"><?php _e('Sorry, an error occured. ', 'andrina-lite'); ?></p>
                        <?php } ?>
                        <form class="contactform" id="contactForm" action="<?php the_permalink(); ?>" method="post">
                            <label>Name <span class="required"></span></label>
                            <input type="text" name="contactName" id="contactName" value="<?php
                            if (isset($_POST['contactName']))
                                echo $_POST['contactName'];
                            ?>" class="text required requiredField" />
                                   <?php if ($nameError != '') { ?>
                                <span class="error"> <?php _e('$nameError', 'andrina-lite'); ?> </span>                           
                            <?php } ?>
                            <label><?php _e('Email ', 'andrina-lite'); ?><span class="required"></span></label>
                            <input type="text" name="email" id="email" value="<?php
                            if (isset($_POST['email']))
                                echo $_POST['email'];
                            ?>" class="text required requiredField email" />
                                   <?php if ($emailError != '') { ?>
                                <span class="error"> <?php _e('$emailError', 'andrina-lite'); ?> </span>                            
                            <?php } ?>
                            <label class="last-label"><?php _e('Your Message ', 'andrina-lite'); ?><span class="required"></span></label>
                            <textarea name="comments" id="commentsText" rows="20" cols="30" class="required requiredField message"><?php
                                if (isset($_POST['comments'])) {
                                    if (function_exists('stripslashes')) {
                                        echo stripslashes($_POST['comments']);
                                    } else {
                                        echo $_POST['comments'];
                                    }
                                }
                                ?></textarea>
                            <?php if ($commentError != '') { ?>
                                <span class="error"> <?php _e('$commentError', 'andrina-lite'); ?> </span>
                            <?php } ?>

                            <?php
                            if (andrina_get_option('andrina_contact_captcha') == 'on') {
                                ?>


                                <div class="g-recaptcha" data-sitekey="<?php echo esc_attr(andrina_get_option('andrina_captcha_site_key')); ?>">
                                
                                </div><span class="error captcha"> <?php $errMsg; ?> </span>
                                <br/>

                                <?php
                            }
                            ?>
                            <input class="btnSubmit sub_btn" type="submit" name="submit" value="<?php _e('Submit', 'andrina-lite'); ?>"/>
                            <input type="hidden" name="submitted" id="submitted" value="true" />
                        </form>  
                    <?php } ?>		  
                </div>
            </div>
        </div>
        <div class="col-md-4 col-sm-4">
            <!--Start Sidebar-->
            <?php get_sidebar(); ?>
            <!--End Sidebar-->
        </div>
    </div>
</div>
<?php
get_footer();
